clj-circuit-breaker.breaker-factory


create-circuit-breakerclj

(create-circuit-breaker circuit-breakers-config
                        default-timeout
                        default-fail-threshold
                        max-allowed-timeout)

a factory method to create a circuit breaker component, please note the system should not require the component but just the factory and protocol. there is a function overload incase you want to use your own circuit breaker strategy

a factory method to create a circuit breaker component, please note the system should not require the component but just the factory and protocol.
there is a function overload incase you want to use your own circuit breaker strategy
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries